==> jc-1.4.0.tar.gz: javax/rmi/CORBA/ObjectImpl.c <==
// public class javax.rmi.CORBA.ObjectImpl

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 61b181df0f842ae4 javax_rmi_BAD__5fOPERATION
// @dep_class 5219dfd5835e78ba javax_rmi_CORBA_ObjectImpl

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_rmi_BAD__5fOPERATION
// @dep_header javax_rmi_CORBA_ObjectImpl

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/rmi/BAD__5fOPERATION.h"
#include "javax/rmi/CORBA/ObjectImpl.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_javax_rmi_CORBA_ObjectImpl$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_rmi_CORBA_ObjectImpl$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_rmi_CORBA_ObjectImpl$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_rmi_CORBA_ObjectImpl$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_rmi_CORBA_ObjectImpl$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_rmi_CORBA_ObjectImpl$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_rmi_CORBA_ObjectImpl$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_rmi_CORBA_ObjectImpl, _init$52f4ad9f2989aeee);

void
_jc_javax_rmi_CORBA_ObjectImpl$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_rmi_CORBA_ObjectImpl$object *this)
{
	struct _jc_javax_rmi_CORBA_ObjectImpl$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(4);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public javax.rmi.CORBA.ObjectImpl _orb()
//

static _jc_linenum _jc_javax_rmi_CORBA_ObjectImpl$linenum_table$__5forb$f24a92ad29cb213f[];

static const unsigned char _jc_javax_rmi_CORBA_ObjectImpl$param_ptypes$__5forb$f24a92ad29cb213f[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_rmi_CORBA_ObjectImpl$method_info$__5forb$f24a92ad29cb213f = {
	.name=			"_orb",
	.signature=		"()Ljavax/rmi/CORBA/ObjectImpl;",
	.class=			&_jc_javax_rmi_CORBA_ObjectImpl$type,
	.return_type=		&_jc_javax_rmi_CORBA_ObjectImpl$type,
	.param_ptypes=		&_jc_javax_rmi_CORBA_ObjectImpl$param_ptypes$__5forb$f24a92ad29cb213f,
	.signature_hash=	_JC_JLONG(0xf24a92ad29cb213f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_rmi_CORBA_ObjectImpl$method$__5forb$f24a92ad29cb213f,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_rmi_CORBA_ObjectImpl$vtable, javax_rmi_CORBA_ObjectImpl.__5forb$f24a92ad29cb213f) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_rmi_CORBA_ObjectImpl$linenum_table$__5forb$f24a92ad29cb213f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_rmi_CORBA_ObjectImpl, __5forb$f24a92ad29cb213f);

_jc_javax_rmi_CORBA_ObjectImpl$object *
_jc_javax_rmi_CORBA_ObjectImpl$method$__5forb$f24a92ad29cb213f(_jc_env *const env, _jc_javax_rmi_CORBA_ObjectImpl$object *this)
{
	struct _jc_javax_rmi_CORBA_ObjectImpl$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(6);				// 0
	return _JC_NULL;
}

//
// public java.lang.String object_to_string(javax.rmi.CORBA.ObjectImpl) throws javax.rmi.BAD_OPERATION
//

static _jc_linenum _jc_javax_rmi_CORBA_ObjectImpl$linenum_table$object__5fto__5fstring$5dd32cbc824920ca[];

static const unsigned char _jc_javax_rmi_CORBA_ObjectImpl$param_ptypes$object__5fto__5fstring$5dd32cbc824920ca[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_javax_rmi_CORBA_ObjectImpl$exceptions$object__5fto__5fstring$5dd32cbc824920ca[] = {
	&_jc_javax_rmi_BAD__5fOPERATION$type
};

static _jc_type *const _jc_javax_rmi_CORBA_ObjectImpl$param_types$object__5fto__5fstring$5dd32cbc824920ca[] = {
	&_jc_javax_rmi_CORBA_ObjectImpl$type
};

_jc_method _jc_javax_rmi_CORBA_ObjectImpl$method_info$object__5fto__5fstring$5dd32cbc824920ca = {
	.name=			"object_to_string",
	.signature=		"(Ljavax/rmi/CORBA/ObjectImpl;)Ljava/lang/String;",
	.class=			&_jc_javax_rmi_CORBA_ObjectImpl$type,
	.param_types=		&_jc_javax_rmi_CORBA_ObjectImpl$param_types$object__5fto__5fstring$5dd32cbc824920ca,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_javax_rmi_CORBA_ObjectImpl$param_ptypes$object__5fto__5fstring$5dd32cbc824920ca,
	.signature_hash=	_JC_JLONG(0x5dd32cbc824920ca),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_rmi_CORBA_ObjectImpl$method$object__5fto__5fstring$5dd32cbc824920ca,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_rmi_CORBA_ObjectImpl$vtable, javax_rmi_CORBA_ObjectImpl.object__5fto__5fstring$5dd32cbc824920ca) / sizeof(void *),
	.num_parameters=	1,
	.num_exceptions=	1,
	.exceptions=		&_jc_javax_rmi_CORBA_ObjectImpl$exceptions$object__5fto__5fstring$5dd32cbc824920ca,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_rmi_CORBA_ObjectImpl$linenum_table$object__5fto__5fstring$5dd32cbc824920ca
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_rmi_CORBA_ObjectImpl, object__5fto__5fstring$5dd32cbc824920ca);

_jc_java_lang_String$object *
_jc_javax_rmi_CORBA_ObjectImpl$method$object__5fto__5fstring$5dd32cbc824920ca(_jc_env *const env, _jc_javax_rmi_CORBA_ObjectImpl$object *this, _jc_javax_rmi_CORBA_ObjectImpl$object *param0)
{
	struct _jc_javax_rmi_CORBA_ObjectImpl$object *r0;
	struct _jc_javax_rmi_CORBA_ObjectImpl$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(8);				// 0
	return _JC_NULL;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_rmi_CORBA_ObjectImpl$methods[] = {
	&_jc_javax_rmi_CORBA_ObjectImpl$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_rmi_CORBA_ObjectImpl$method_info$__5forb$f24a92ad29cb213f,
	&_jc_javax_rmi_CORBA_ObjectImpl$method_info$object__5fto__5fstring$5dd32cbc824920ca
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_rmi_CORBA_ObjectImpl$instanceof_hash_bucket_58[] = {
	&_jc_javax_rmi_CORBA_ObjectImpl$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_rmi_CORBA_ObjectImpl$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_rmi_CORBA_ObjectImpl$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[58]=	_jc_javax_rmi_CORBA_ObjectImpl$instanceof_hash_bucket_58,
	[113]=	_jc_javax_rmi_CORBA_ObjectImpl$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_rmi_CORBA_ObjectImpl$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "javax/rmi/BAD_OPERATION",	_JC_JLONG(0x61b181df0f842ae4) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_rmi_CORBA_ObjectImpl$vtype _jc_javax_rmi_CORBA_ObjectImpl$type = {
    .type= {
	.name=			"javax/rmi/CORBA/ObjectImpl",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x5219dfd5835e78ba),
		.source_file=		"ObjectImpl.java",
		.instance_size=		sizeof(_jc_javax_rmi_CORBA_ObjectImpl$refs) + sizeof(_jc_javax_rmi_CORBA_ObjectImpl$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_javax_rmi_CORBA_ObjectImpl$methods) / sizeof(*_jc_javax_rmi_CORBA_ObjectImpl$methods),
		.methods=		_jc_javax_rmi_CORBA_ObjectImpl$methods,
		.instanceof_hash_table=	_jc_javax_rmi_CORBA_ObjectImpl$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_javax_rmi_CORBA_ObjectImpl$class_depends) / sizeof(*_jc_javax_rmi_CORBA_ObjectImpl$class_depends),
		.class_depends=		_jc_javax_rmi_CORBA_ObjectImpl$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_rmi_CORBA_ObjectImpl= {
	    .__5forb$f24a92ad29cb213f=
		&_jc_javax_rmi_CORBA_ObjectImpl$method$__5forb$f24a92ad29cb213f,
	    .object__5fto__5fstring$5dd32cbc824920ca=
		&_jc_javax_rmi_CORBA_ObjectImpl$method$object__5fto__5fstring$5dd32cbc824920ca,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/rmi/CORBA/ObjectImpl.c <==
// public class javax.rmi.CORBA.ObjectImpl

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 61b181df0f842ae4 javax_rmi_BAD__5fOPERATION
// @dep_class 5219dfd5835e78ba javax_rmi_CORBA_ObjectImpl

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_rmi_BAD__5fOPERATION
// @dep_header javax_rmi_CORBA_ObjectImpl

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/rmi/BAD__5fOPERATION.h"
#include "javax/rmi/CORBA/ObjectImpl.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_javax_rmi_CORBA_ObjectImpl$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_rmi_CORBA_ObjectImpl$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_rmi_CORBA_ObjectImpl$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_rmi_CORBA_ObjectImpl$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_rmi_CORBA_ObjectImpl$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_rmi_CORBA_ObjectImpl$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_rmi_CORBA_ObjectImpl$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_rmi_CORBA_ObjectImpl, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_javax_rmi_CORBA_ObjectImpl$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_rmi_CORBA_ObjectImpl$object *this)
{
	struct _jc_javax_rmi_CORBA_ObjectImpl$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(4);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public javax.rmi.CORBA.ObjectImpl _orb()
//

static _jc_linenum _jc_javax_rmi_CORBA_ObjectImpl$linenum_table$__5forb$f24a92ad29cb213f[];

static const unsigned char _jc_javax_rmi_CORBA_ObjectImpl$param_ptypes$__5forb$f24a92ad29cb213f[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_rmi_CORBA_ObjectImpl$method_info$__5forb$f24a92ad29cb213f = {
	.name=			"_orb",
	.signature=		"()Ljavax/rmi/CORBA/ObjectImpl;",
	.class=			&_jc_javax_rmi_CORBA_ObjectImpl$type,
	.return_type=		&_jc_javax_rmi_CORBA_ObjectImpl$type,
	.param_ptypes=		&_jc_javax_rmi_CORBA_ObjectImpl$param_ptypes$__5forb$f24a92ad29cb213f,
	.signature_hash=	_JC_JLONG(0xf24a92ad29cb213f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_rmi_CORBA_ObjectImpl$method$__5forb$f24a92ad29cb213f,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_rmi_CORBA_ObjectImpl$vtable, javax_rmi_CORBA_ObjectImpl.__5forb$f24a92ad29cb213f) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_rmi_CORBA_ObjectImpl$linenum_table$__5forb$f24a92ad29cb213f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_rmi_CORBA_ObjectImpl, __5forb$f24a92ad29cb213f);

_jc_javax_rmi_CORBA_ObjectImpl$object * _JC_JCNI_ATTR
_jc_javax_rmi_CORBA_ObjectImpl$method$__5forb$f24a92ad29cb213f(_jc_env *const env, _jc_javax_rmi_CORBA_ObjectImpl$object *this)
{
	struct _jc_javax_rmi_CORBA_ObjectImpl$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(6);				// 0
	return _JC_NULL;
}

//
// public java.lang.String object_to_string(javax.rmi.CORBA.ObjectImpl) throws javax.rmi.BAD_OPERATION
//

static _jc_linenum _jc_javax_rmi_CORBA_ObjectImpl$linenum_table$object__5fto__5fstring$5dd32cbc824920ca[];

static const unsigned char _jc_javax_rmi_CORBA_ObjectImpl$param_ptypes$object__5fto__5fstring$5dd32cbc824920ca[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_javax_rmi_CORBA_ObjectImpl$exceptions$object__5fto__5fstring$5dd32cbc824920ca[] = {
	&_jc_javax_rmi_BAD__5fOPERATION$type
};

static _jc_type *const _jc_javax_rmi_CORBA_ObjectImpl$param_types$object__5fto__5fstring$5dd32cbc824920ca[] = {
	&_jc_javax_rmi_CORBA_ObjectImpl$type
};

_jc_method _jc_javax_rmi_CORBA_ObjectImpl$method_info$object__5fto__5fstring$5dd32cbc824920ca = {
	.name=			"object_to_string",
	.signature=		"(Ljavax/rmi/CORBA/ObjectImpl;)Ljava/lang/String;",
	.class=			&_jc_javax_rmi_CORBA_ObjectImpl$type,
	.param_types=		&_jc_javax_rmi_CORBA_ObjectImpl$param_types$object__5fto__5fstring$5dd32cbc824920ca,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_javax_rmi_CORBA_ObjectImpl$param_ptypes$object__5fto__5fstring$5dd32cbc824920ca,
	.signature_hash=	_JC_JLONG(0x5dd32cbc824920ca),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_rmi_CORBA_ObjectImpl$method$object__5fto__5fstring$5dd32cbc824920ca,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_rmi_CORBA_ObjectImpl$vtable, javax_rmi_CORBA_ObjectImpl.object__5fto__5fstring$5dd32cbc824920ca) / sizeof(void *),
	.num_parameters=	1,
	.num_exceptions=	1,
	.exceptions=		&_jc_javax_rmi_CORBA_ObjectImpl$exceptions$object__5fto__5fstring$5dd32cbc824920ca,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_rmi_CORBA_ObjectImpl$linenum_table$object__5fto__5fstring$5dd32cbc824920ca
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_rmi_CORBA_ObjectImpl, object__5fto__5fstring$5dd32cbc824920ca);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_javax_rmi_CORBA_ObjectImpl$method$object__5fto__5fstring$5dd32cbc824920ca(_jc_env *const env, _jc_javax_rmi_CORBA_ObjectImpl$object *this, _jc_javax_rmi_CORBA_ObjectImpl$object *param0)
{
	struct _jc_javax_rmi_CORBA_ObjectImpl$object *r0;
	struct _jc_javax_rmi_CORBA_ObjectImpl$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(8);				// 0
	return _JC_NULL;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_rmi_CORBA_ObjectImpl$methods[] = {
	&_jc_javax_rmi_CORBA_ObjectImpl$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_rmi_CORBA_ObjectImpl$method_info$__5forb$f24a92ad29cb213f,
	&_jc_javax_rmi_CORBA_ObjectImpl$method_info$object__5fto__5fstring$5dd32cbc824920ca
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_rmi_CORBA_ObjectImpl$instanceof_hash_bucket_58[] = {
	&_jc_javax_rmi_CORBA_ObjectImpl$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_rmi_CORBA_ObjectImpl$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_rmi_CORBA_ObjectImpl$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[58]=	_jc_javax_rmi_CORBA_ObjectImpl$instanceof_hash_bucket_58,
	[101]=	_jc_javax_rmi_CORBA_ObjectImpl$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_rmi_CORBA_ObjectImpl$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "javax/rmi/BAD_OPERATION",	_JC_JLONG(0x61b181df0f842ae4) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_rmi_CORBA_ObjectImpl$vtype _jc_javax_rmi_CORBA_ObjectImpl$type = {
    .type= {
	.name=			"javax/rmi/CORBA/ObjectImpl",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x5219dfd5835e78ba),
		.source_file=		"ObjectImpl.java",
		.instance_size=		sizeof(_jc_javax_rmi_CORBA_ObjectImpl$refs) + sizeof(_jc_javax_rmi_CORBA_ObjectImpl$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_javax_rmi_CORBA_ObjectImpl$methods) / sizeof(*_jc_javax_rmi_CORBA_ObjectImpl$methods),
		.methods=		_jc_javax_rmi_CORBA_ObjectImpl$methods,
		.instanceof_hash_table=	_jc_javax_rmi_CORBA_ObjectImpl$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_javax_rmi_CORBA_ObjectImpl$class_depends) / sizeof(*_jc_javax_rmi_CORBA_ObjectImpl$class_depends),
		.class_depends=		_jc_javax_rmi_CORBA_ObjectImpl$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_rmi_CORBA_ObjectImpl= {
	    .__5forb$f24a92ad29cb213f=
		&_jc_javax_rmi_CORBA_ObjectImpl$method$__5forb$f24a92ad29cb213f,
	    .object__5fto__5fstring$5dd32cbc824920ca=
		&_jc_javax_rmi_CORBA_ObjectImpl$method$object__5fto__5fstring$5dd32cbc824920ca,
	},
    }
};
